Nurex
=======
Nuclear Reaction Cross Section calculator.
Nurex is a library for Glauber Model nuclear reaction caclulation. 
The library is written in C++ with Python bindings.
Note: This is work in progress. At the moment only basic documentation is available here. The rest will come.

#### Web Interface
WebUI to this libary is running here: https://www.isotopea.com/nurex/

#### Physics Manual
https://www.isotopea.com/nurex/nurex_v1.6.pdf



	
Build and Installation
======================

Python nurex modules requires python 3.7+ and is available for Linux via pip:
```
pip install pynurex
```

For basic usage see [Python](docs/python.md) and [JSON format](docs/json_format.md) documentation.
